@@ -1,5 +1,9 @@
 #include "kiss.h"
 
+#if defined (__GLIBC__) && __GLIBC__ >=2
+  #define environ __environ
+#endif
+
 int doprintenv (Stringstack s)
 {
     register int
